"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Clustering = void 0;
const logs = require("../logs");
class Clustering {
    constructor(config, table, schema) {
        this.updateCluster = async (metaData) => {
            const clustering = { fields: this.config.clustering };
            metaData.clustering = clustering;
            logs.updatedClustering(this.config.clustering.join(","));
            return Promise.resolve();
        };
        this.removeCluster = async (metaData) => {
            metaData.clustering = null;
            logs.removedClustering(this.table.id);
            return Promise.resolve();
        };
        this.updateClustering = async (metaData) => {
            /** Return if invalid config */
            if (await this.hasInvalidFields(metaData))
                return Promise.resolve();
            return !!this.config.clustering && !!this.config.clustering.length
                ? this.updateCluster(metaData)
                : this.removeCluster(metaData);
        };
        this.config = config;
        this.table = table;
        this.schema = schema;
    }
    hasValidTableReference() {
        logs.invalidTableReference();
        return !!this.table;
    }
    async hasInvalidFields(metaData) {
        const { clustering = [] } = this.config;
        if (!clustering)
            return Promise.resolve(false);
        const fieldNames = metaData
            ? metaData.schema.fields.map(($) => $.name)
            : [];
        const invalidFields = clustering.filter(($) => !fieldNames.includes($));
        if (invalidFields.length) {
            logs.invalidClustering(invalidFields.join(","));
            return Promise.resolve(true);
        }
        return Promise.resolve(false);
    }
}
exports.Clustering = Clustering;
